@@ -2,3 +2,7 @@ from imagen_pytorch.imagen_pytorch import Imagen, Unet
 from imagen_pytorch.imagen_pytorch import BaseUnet64, SRUnet256, SRUnet1024
 from imagen_pytorch.trainer import ImagenTrainer
 from imagen_pytorch.version import __version__
+
+# imagen using the elucidated ddpm from Tero Karras' new paper
+
+from imagen_pytorch.elucidated_imagen import ElucidatedImagen
